@@ -5,32 +5,34 @@
 ##' In probe-matching, one attempts to minimize the discrepancy between simulated and actual data, as measured by a set of summary statistics called \emph{probes}.
 ##' In \pkg{pomp}, this discrepancy is measured using the \dQuote{synthetic likelihood} as defined by Wood (2010).
 ##'
-##' @name probe_matching
+##' @docType methods
+##' @name probe matching
 ##' @rdname probe_match
 ##' @aliases probe_objfun probe_objfun,missing-method probe_objfun,ANY-method
 ##' @include probe.R plot.R
 ##' @author Aaron A. King
-##' @family summary_stats_methods
-##' @family estimation_methods
-##' @seealso \code{\link{optim}} \code{\link[subplex]{subplex}} \code{\link[nloptr]{nloptr}}
+##' @concept probe matching
+##' @concept synthetic likelihood
+##' @family summary statistic-based methods
+##' @family estimation methods
+##' @family methods based on maximization
+##' @seealso \code{\link[stats]{optim}} \code{\link[subplex]{subplex}} \code{\link[nloptr]{nloptr}}
 ##'
 ##' @param est character vector; the names of parameters to be estimated.
-##'
 ##' @param fail.value optional numeric scalar;
 ##' if non-\code{NA}, this value is substituted for non-finite values of the objective function.
 ##' It should be a large number (i.e., bigger than any legitimate values the objective function is likely to take).
-##'
 ##' @param seed  integer.
 ##' When fitting, it is often best to fix the seed of the random-number generator (RNG).
 ##' This is accomplished by setting \code{seed} to an integer.
 ##' By default, \code{seed = NULL}, which does not alter the RNG state.
-##'
+##' 
 ##' @inheritParams probe
 ##' @inheritParams pomp
 ##'
 ##' @return
 ##' \code{probe_objfun} constructs a stateful objective function for probe matching.
-##' Specifically, \code{probe_objfun} returns an object of class \sQuote{probe_match_objfun}, which is a function suitable for use in an \code{\link{optim}}-like optimizer.
+##' Specifically, \code{probe_objfun} returns an object of class \sQuote{probe_match_objfun}, which is a function suitable for use in an \code{\link[stats]{optim}}-like optimizer.
 ##' In particular, this function takes a single numeric-vector argument that is assumed to contain the parameters named in \code{est}, in that order.
 ##' When called, it will return the negative synthetic log likelihood for the probes specified.
 ##' It is a stateful function:
@@ -212,7 +214,7 @@ pmof.internal <- function (object,
 
   pompLoad(object,verbose=verbose)
 
-  ofun <- function (par) {
+  ofun <- function (par = numeric(0)) {
     params[idx] <- par
     coef(object,transform=TRUE) <<- params
     loglik <<- probe.eval(object)
